Transfer Mechanisms
===================

**Core class**:

* `TransferMechanism`

**Subtypes**:

.. _TransferMechanism_Subtypes:

.. toctree::
   :maxdepth: 1

   RecurrentTransferMechanism
   LCAMechanism
   KWTAMechanism
   KohonenMechanism
   ContrastiveHebbianMechanism